Getting started
===============

Basic usage
-----------

.. todo::

    Example usage should come from rdeps.  Until then, see the examples…

* :ref:`attrdict <attrdict-examples>`
* :ref:`colourise <colourise-examples>`
* :ref:`config <config-examples>`
* :ref:`context <context-examples>`
* :ref:`debug <debug-examples>`
* :ref:`entry <entry-examples>`
* :ref:`git <git-examples>`
* :ref:`httplib2_certs <httplib2_certs-examples>`
* :ref:`human_time <human_time-examples>`
* :ref:`i18n <i18n-examples>`
* :ref:`iso_8601 <iso_8601-examples>`
* :ref:`json_datetime <json_datetime-examples>`
* :ref:`pager <pager-examples>`
* :ref:`pip_support <pip_support-examples>`
* :ref:`template <template-examples>`
* :ref:`timer <timer-examples>`
* :ref:`xdg_basedir <xdg_basedir-examples>`
